/****************************************************************************
** Meta object code from reading C++ file 'rfbclient.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/krfb-17.08.3/krfb/rfbclient.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rfbclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RfbClient_t {
    QByteArrayData data[11];
    char stringdata0[143];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RfbClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RfbClient_t qt_meta_stringdata_RfbClient = {
    {
QT_MOC_LITERAL(0, 0, 9), // "RfbClient"
QT_MOC_LITERAL(1, 10, 21), // "controlEnabledChanged"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 7), // "enabled"
QT_MOC_LITERAL(4, 41, 17), // "holdStatusChanged"
QT_MOC_LITERAL(5, 59, 6), // "onHold"
QT_MOC_LITERAL(6, 66, 17), // "setControlEnabled"
QT_MOC_LITERAL(7, 84, 9), // "setOnHold"
QT_MOC_LITERAL(8, 94, 15), // "closeConnection"
QT_MOC_LITERAL(9, 110, 17), // "onSocketActivated"
QT_MOC_LITERAL(10, 128, 14) // "controlEnabled"

    },
    "RfbClient\0controlEnabledChanged\0\0"
    "enabled\0holdStatusChanged\0onHold\0"
    "setControlEnabled\0setOnHold\0closeConnection\0"
    "onSocketActivated\0controlEnabled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RfbClient[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       2,   58, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    1,   47,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   50,    2, 0x0a /* Public */,
       7,    1,   53,    2, 0x0a /* Public */,
       8,    0,   56,    2, 0x0a /* Public */,
       9,    0,   57,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    5,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
      10, QMetaType::Bool, 0x00495103,
       5, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,

       0        // eod
};

void RfbClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RfbClient *_t = static_cast<RfbClient *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->controlEnabledChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->holdStatusChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->setControlEnabled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->setOnHold((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 4: _t->closeConnection(); break;
        case 5: _t->onSocketActivated(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (RfbClient::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RfbClient::controlEnabledChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (RfbClient::*_t)(bool );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&RfbClient::holdStatusChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        RfbClient *_t = static_cast<RfbClient *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->controlEnabled(); break;
        case 1: *reinterpret_cast< bool*>(_v) = _t->isOnHold(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        RfbClient *_t = static_cast<RfbClient *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setControlEnabled(*reinterpret_cast< bool*>(_v)); break;
        case 1: _t->setOnHold(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject RfbClient::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_RfbClient.data,
      qt_meta_data_RfbClient,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RfbClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RfbClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RfbClient.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RfbClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void RfbClient::controlEnabledChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void RfbClient::holdStatusChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
struct qt_meta_stringdata_PendingRfbClient_t {
    QByteArrayData data[9];
    char stringdata0[86];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PendingRfbClient_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PendingRfbClient_t qt_meta_stringdata_PendingRfbClient = {
    {
QT_MOC_LITERAL(0, 0, 16), // "PendingRfbClient"
QT_MOC_LITERAL(1, 17, 8), // "finished"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 10), // "RfbClient*"
QT_MOC_LITERAL(4, 38, 6), // "client"
QT_MOC_LITERAL(5, 45, 16), // "processNewClient"
QT_MOC_LITERAL(6, 62, 6), // "accept"
QT_MOC_LITERAL(7, 69, 9), // "newClient"
QT_MOC_LITERAL(8, 79, 6) // "reject"

    },
    "PendingRfbClient\0finished\0\0RfbClient*\0"
    "client\0processNewClient\0accept\0newClient\0"
    "reject"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PendingRfbClient[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   37,    2, 0x09 /* Protected */,
       6,    1,   38,    2, 0x09 /* Protected */,
       8,    0,   41,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    7,
    QMetaType::Void,

       0        // eod
};

void PendingRfbClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        PendingRfbClient *_t = static_cast<PendingRfbClient *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast< RfbClient*(*)>(_a[1]))); break;
        case 1: _t->processNewClient(); break;
        case 2: _t->accept((*reinterpret_cast< RfbClient*(*)>(_a[1]))); break;
        case 3: _t->reject(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RfbClient* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RfbClient* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        void **func = reinterpret_cast<void **>(_a[1]);
        {
            typedef void (PendingRfbClient::*_t)(RfbClient * );
            if (*reinterpret_cast<_t *>(func) == static_cast<_t>(&PendingRfbClient::finished)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject PendingRfbClient::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_PendingRfbClient.data,
      qt_meta_data_PendingRfbClient,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *PendingRfbClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PendingRfbClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PendingRfbClient.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PendingRfbClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void PendingRfbClient::finished(RfbClient * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
