#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'mainwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWIDGET_H
#define UI_MAINWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_MainWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QLabel *krfbIconLabel;
    QVBoxLayout *rightLayout;
    QLabel *titleLabel;
    QLabel *aboutLabel;
    QCheckBox *enableSharingCheckBox;
    QGroupBox *detailsGroupBox;
    QVBoxLayout *verticalLayout;
    QFormLayout *addressFormLayout;
    QLabel *addressLabel;
    QGridLayout *addressGridLayout;
    QToolButton *addressAboutButton;
    QLabel *addressDisplayLabel;
    QFormLayout *passwordFormLayout;
    QLabel *passwordLabel;
    QGridLayout *passwordGridLayout;
    QToolButton *passwordEditButton;
    QLabel *passwordDisplayLabel;
    QGroupBox *unattendedGroupBox;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *unattendedDetailsLayout;
    QLabel *unattendedAboutLabel;
    QToolButton *unattendedAboutButton;
    QHBoxLayout *unattendedSettingsLayout;
    QCheckBox *enableUnattendedCheckBox;
    QPushButton *unattendedPasswordButton;
    QVBoxLayout *tpContactsLayout;

    void setupUi(QWidget *MainWidget)
    {
        if (MainWidget->objectName().isEmpty())
            MainWidget->setObjectName(QStringLiteral("MainWidget"));
        MainWidget->resize(600, 340);
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(MainWidget->sizePolicy().hasHeightForWidth());
        MainWidget->setSizePolicy(sizePolicy);
        MainWidget->setMinimumSize(QSize(600, 340));
        MainWidget->setMaximumSize(QSize(16777215, 16777215));
        horizontalLayout = new QHBoxLayout(MainWidget);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        krfbIconLabel = new QLabel(MainWidget);
        krfbIconLabel->setObjectName(QStringLiteral("krfbIconLabel"));
        krfbIconLabel->setMinimumSize(QSize(128, 128));
        krfbIconLabel->setMaximumSize(QSize(128, 128));

        horizontalLayout->addWidget(krfbIconLabel);

        rightLayout = new QVBoxLayout();
        rightLayout->setObjectName(QStringLiteral("rightLayout"));
        rightLayout->setSizeConstraint(QLayout::SetMaximumSize);
        titleLabel = new QLabel(MainWidget);
        titleLabel->setObjectName(QStringLiteral("titleLabel"));
        QSizePolicy sizePolicy1(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(titleLabel->sizePolicy().hasHeightForWidth());
        titleLabel->setSizePolicy(sizePolicy1);
        titleLabel->setMinimumSize(QSize(400, 20));
        titleLabel->setMaximumSize(QSize(16777215, 40));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        titleLabel->setFont(font);
        titleLabel->setAlignment(Qt::AlignCenter);

        rightLayout->addWidget(titleLabel);

        aboutLabel = new QLabel(MainWidget);
        aboutLabel->setObjectName(QStringLiteral("aboutLabel"));
        sizePolicy1.setHeightForWidth(aboutLabel->sizePolicy().hasHeightForWidth());
        aboutLabel->setSizePolicy(sizePolicy1);
        aboutLabel->setMinimumSize(QSize(400, 40));
        aboutLabel->setMaximumSize(QSize(16777215, 80));
        aboutLabel->setWordWrap(true);

        rightLayout->addWidget(aboutLabel);

        enableSharingCheckBox = new QCheckBox(MainWidget);
        enableSharingCheckBox->setObjectName(QStringLiteral("enableSharingCheckBox"));
        QSizePolicy sizePolicy2(QSizePolicy::Minimum, QSizePolicy::MinimumExpanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(enableSharingCheckBox->sizePolicy().hasHeightForWidth());
        enableSharingCheckBox->setSizePolicy(sizePolicy2);
        enableSharingCheckBox->setMinimumSize(QSize(400, 20));
        enableSharingCheckBox->setMaximumSize(QSize(16777215, 40));

        rightLayout->addWidget(enableSharingCheckBox);

        detailsGroupBox = new QGroupBox(MainWidget);
        detailsGroupBox->setObjectName(QStringLiteral("detailsGroupBox"));
        detailsGroupBox->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(detailsGroupBox->sizePolicy().hasHeightForWidth());
        detailsGroupBox->setSizePolicy(sizePolicy3);
        detailsGroupBox->setMinimumSize(QSize(0, 100));
        verticalLayout = new QVBoxLayout(detailsGroupBox);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        addressFormLayout = new QFormLayout();
        addressFormLayout->setObjectName(QStringLiteral("addressFormLayout"));
        addressFormLayout->setSizeConstraint(QLayout::SetMaximumSize);
        addressFormLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        addressFormLayout->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        addressLabel = new QLabel(detailsGroupBox);
        addressLabel->setObjectName(QStringLiteral("addressLabel"));
        sizePolicy1.setHeightForWidth(addressLabel->sizePolicy().hasHeightForWidth());
        addressLabel->setSizePolicy(sizePolicy1);

        addressFormLayout->setWidget(0, QFormLayout::LabelRole, addressLabel);

        addressGridLayout = new QGridLayout();
        addressGridLayout->setObjectName(QStringLiteral("addressGridLayout"));
        addressGridLayout->setSizeConstraint(QLayout::SetMaximumSize);
        addressAboutButton = new QToolButton(detailsGroupBox);
        addressAboutButton->setObjectName(QStringLiteral("addressAboutButton"));
        QSizePolicy sizePolicy4(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(addressAboutButton->sizePolicy().hasHeightForWidth());
        addressAboutButton->setSizePolicy(sizePolicy4);
        QIcon icon;
        QString iconThemeName = QStringLiteral("help-about");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        addressAboutButton->setIcon(icon);

        addressGridLayout->addWidget(addressAboutButton, 0, 1, 1, 1);

        addressDisplayLabel = new QLabel(detailsGroupBox);
        addressDisplayLabel->setObjectName(QStringLiteral("addressDisplayLabel"));
        sizePolicy1.setHeightForWidth(addressDisplayLabel->sizePolicy().hasHeightForWidth());
        addressDisplayLabel->setSizePolicy(sizePolicy1);
        addressDisplayLabel->setAlignment(Qt::AlignCenter);

        addressGridLayout->addWidget(addressDisplayLabel, 0, 0, 1, 1);


        addressFormLayout->setLayout(0, QFormLayout::FieldRole, addressGridLayout);


        verticalLayout->addLayout(addressFormLayout);

        passwordFormLayout = new QFormLayout();
        passwordFormLayout->setObjectName(QStringLiteral("passwordFormLayout"));
        passwordFormLayout->setSizeConstraint(QLayout::SetMaximumSize);
        passwordFormLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        passwordFormLayout->setFormAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        passwordLabel = new QLabel(detailsGroupBox);
        passwordLabel->setObjectName(QStringLiteral("passwordLabel"));
        sizePolicy1.setHeightForWidth(passwordLabel->sizePolicy().hasHeightForWidth());
        passwordLabel->setSizePolicy(sizePolicy1);

        passwordFormLayout->setWidget(0, QFormLayout::LabelRole, passwordLabel);

        passwordGridLayout = new QGridLayout();
        passwordGridLayout->setObjectName(QStringLiteral("passwordGridLayout"));
        passwordGridLayout->setSizeConstraint(QLayout::SetMaximumSize);
        passwordEditButton = new QToolButton(detailsGroupBox);
        passwordEditButton->setObjectName(QStringLiteral("passwordEditButton"));
        sizePolicy4.setHeightForWidth(passwordEditButton->sizePolicy().hasHeightForWidth());
        passwordEditButton->setSizePolicy(sizePolicy4);
        QIcon icon1;
        iconThemeName = QStringLiteral("document-edit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QStringLiteral(""), QSize(), QIcon::Normal, QIcon::Off);
        }
        passwordEditButton->setIcon(icon1);

        passwordGridLayout->addWidget(passwordEditButton, 0, 1, 1, 1);

        passwordDisplayLabel = new QLabel(detailsGroupBox);
        passwordDisplayLabel->setObjectName(QStringLiteral("passwordDisplayLabel"));
        sizePolicy1.setHeightForWidth(passwordDisplayLabel->sizePolicy().hasHeightForWidth());
        passwordDisplayLabel->setSizePolicy(sizePolicy1);
        passwordDisplayLabel->setAlignment(Qt::AlignCenter);

        passwordGridLayout->addWidget(passwordDisplayLabel, 0, 0, 1, 1);


        passwordFormLayout->setLayout(0, QFormLayout::FieldRole, passwordGridLayout);


        verticalLayout->addLayout(passwordFormLayout);


        rightLayout->addWidget(detailsGroupBox);

        unattendedGroupBox = new QGroupBox(MainWidget);
        unattendedGroupBox->setObjectName(QStringLiteral("unattendedGroupBox"));
        unattendedGroupBox->setEnabled(false);
        sizePolicy3.setHeightForWidth(unattendedGroupBox->sizePolicy().hasHeightForWidth());
        unattendedGroupBox->setSizePolicy(sizePolicy3);
        verticalLayout_2 = new QVBoxLayout(unattendedGroupBox);
        verticalLayout_2->setObjectName(QStringLiteral("verticalLayout_2"));
        unattendedDetailsLayout = new QHBoxLayout();
        unattendedDetailsLayout->setObjectName(QStringLiteral("unattendedDetailsLayout"));
        unattendedDetailsLayout->setContentsMargins(0, 10, 0, 10);
        unattendedAboutLabel = new QLabel(unattendedGroupBox);
        unattendedAboutLabel->setObjectName(QStringLiteral("unattendedAboutLabel"));
        sizePolicy1.setHeightForWidth(unattendedAboutLabel->sizePolicy().hasHeightForWidth());
        unattendedAboutLabel->setSizePolicy(sizePolicy1);
        unattendedAboutLabel->setMaximumSize(QSize(16777215, 80));
        unattendedAboutLabel->setWordWrap(true);

        unattendedDetailsLayout->addWidget(unattendedAboutLabel);

        unattendedAboutButton = new QToolButton(unattendedGroupBox);
        unattendedAboutButton->setObjectName(QStringLiteral("unattendedAboutButton"));
        sizePolicy4.setHeightForWidth(unattendedAboutButton->sizePolicy().hasHeightForWidth());
        unattendedAboutButton->setSizePolicy(sizePolicy4);
        unattendedAboutButton->setIcon(icon);

        unattendedDetailsLayout->addWidget(unattendedAboutButton);


        verticalLayout_2->addLayout(unattendedDetailsLayout);

        unattendedSettingsLayout = new QHBoxLayout();
        unattendedSettingsLayout->setObjectName(QStringLiteral("unattendedSettingsLayout"));
        unattendedSettingsLayout->setContentsMargins(0, 10, 0, 10);
        enableUnattendedCheckBox = new QCheckBox(unattendedGroupBox);
        enableUnattendedCheckBox->setObjectName(QStringLiteral("enableUnattendedCheckBox"));
        sizePolicy3.setHeightForWidth(enableUnattendedCheckBox->sizePolicy().hasHeightForWidth());
        enableUnattendedCheckBox->setSizePolicy(sizePolicy3);
        enableUnattendedCheckBox->setMaximumSize(QSize(16777215, 80));

        unattendedSettingsLayout->addWidget(enableUnattendedCheckBox);

        unattendedPasswordButton = new QPushButton(unattendedGroupBox);
        unattendedPasswordButton->setObjectName(QStringLiteral("unattendedPasswordButton"));
        sizePolicy3.setHeightForWidth(unattendedPasswordButton->sizePolicy().hasHeightForWidth());
        unattendedPasswordButton->setSizePolicy(sizePolicy3);
        unattendedPasswordButton->setMinimumSize(QSize(0, 0));
        unattendedPasswordButton->setMaximumSize(QSize(320, 80));

        unattendedSettingsLayout->addWidget(unattendedPasswordButton);


        verticalLayout_2->addLayout(unattendedSettingsLayout);


        rightLayout->addWidget(unattendedGroupBox);


        horizontalLayout->addLayout(rightLayout);

        tpContactsLayout = new QVBoxLayout();
        tpContactsLayout->setObjectName(QStringLiteral("tpContactsLayout"));
        tpContactsLayout->setSizeConstraint(QLayout::SetMinimumSize);

        horizontalLayout->addLayout(tpContactsLayout);

#ifndef UI_QT_NO_SHORTCUT
        addressLabel->setBuddy(addressAboutButton);
        passwordLabel->setBuddy(passwordEditButton);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(enableSharingCheckBox, addressAboutButton);
        QWidget::setTabOrder(addressAboutButton, passwordEditButton);
        QWidget::setTabOrder(passwordEditButton, enableUnattendedCheckBox);
        QWidget::setTabOrder(enableUnattendedCheckBox, unattendedPasswordButton);

        retranslateUi(MainWidget);
        QObject::connect(enableSharingCheckBox, SIGNAL(toggled(bool)), detailsGroupBox, SLOT(setEnabled(bool)));
        QObject::connect(enableSharingCheckBox, SIGNAL(toggled(bool)), unattendedGroupBox, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(MainWidget);
    } // setupUi

    void retranslateUi(QWidget *MainWidget)
    {
        krfbIconLabel->setText(QString());
#ifndef UI_QT_NO_WHATSTHIS
        titleLabel->setWhatsThis(tr2i18n("KDE Desktop Sharing", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        titleLabel->setText(tr2i18n("KDE Desktop Sharing", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        aboutLabel->setWhatsThis(tr2i18n("KDE Desktop Sharing", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        aboutLabel->setText(tr2i18n("KDE Desktop Sharing allows you to grant permission to someone at a remote location for viewing and possibly controlling your desktop.", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        enableSharingCheckBox->setWhatsThis(tr2i18n("Starts/Stops Remote Desktop Sharing", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        enableSharingCheckBox->setText(tr2i18n("&Enable Desktop Sharing", Q_NULLPTR));
        detailsGroupBox->setTitle(tr2i18n("Connection Details", Q_NULLPTR));
        addressLabel->setText(tr2i18n("&Address", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        addressAboutButton->setWhatsThis(tr2i18n("More about this address", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        addressAboutButton->setText(tr2i18n("About", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        addressDisplayLabel->setWhatsThis(tr2i18n("Address required by remote users to connect to your desktop. Click about button on the right for more info.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        addressDisplayLabel->setText(tr2i18n("127.0.0.1 : 5900", Q_NULLPTR));
        passwordLabel->setText(tr2i18n("&Password", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        passwordEditButton->setWhatsThis(tr2i18n("Edit/Save Desktop Sharing Password", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        passwordEditButton->setText(tr2i18n("Edit", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        passwordDisplayLabel->setWhatsThis(tr2i18n("Password required by remote users to connect to your desktop. Click the edit button on the right to change password.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        passwordDisplayLabel->setText(tr2i18n("TemporaryPassword", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        unattendedGroupBox->setWhatsThis(tr2i18n("Unattended Access allows a remote user with the password to gain control to your desktop without your explicit confirmation.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        unattendedGroupBox->setTitle(tr2i18n("Unattended Access", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        unattendedAboutLabel->setWhatsThis(tr2i18n("Unattended Access allows a remote user with the password to gain control to your desktop without your explicit confirmation. Click \"About\" button on right to know more.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        unattendedAboutLabel->setText(tr2i18n("Unattended Access allows a remote user with the password to gain control to your desktop without your explicit confirmation.", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        unattendedAboutButton->setWhatsThis(tr2i18n("Know more about Unattended Access", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        unattendedAboutButton->setText(tr2i18n("About", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        enableUnattendedCheckBox->setWhatsThis(tr2i18n("Starts/Stops unattended access to your desktop. Click on button on right to change password, and \"About\" button to know more.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        enableUnattendedCheckBox->setText(tr2i18n("Enable &Unattended Access", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        unattendedPasswordButton->setWhatsThis(tr2i18n("Change password for Unattended Access", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        unattendedPasswordButton->setText(tr2i18n("&Change Unattended Password", Q_NULLPTR));
        Q_UNUSED(MainWidget);
    } // retranslateUi

};

namespace Ui {
    class MainWidget: public Ui_MainWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAINWIDGET_H

