#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'connectionwidget.ui'
**
** Created by: Qt User Interface Compiler version 5.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONNECTIONWIDGET_H
#define UI_CONNECTIONWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_ConnectionWidget
{
public:
    QHBoxLayout *hboxLayout;
    QLabel *pixmapLabel;
    QVBoxLayout *vboxLayout;
    QLabel *TextLabel5;
    QLabel *mainTextLabel;
    QHBoxLayout *hboxLayout1;
    QLabel *TextLabel1;
    QLabel *remoteHost;
    QCheckBox *cbAllowRemoteControl;

    void setupUi(QWidget *ConnectionWidget)
    {
        if (ConnectionWidget->objectName().isEmpty())
            ConnectionWidget->setObjectName(QStringLiteral("ConnectionWidget"));
        ConnectionWidget->resize(500, 212);
        hboxLayout = new QHBoxLayout(ConnectionWidget);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        pixmapLabel = new QLabel(ConnectionWidget);
        pixmapLabel->setObjectName(QStringLiteral("pixmapLabel"));
        QSizePolicy sizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(pixmapLabel->sizePolicy().hasHeightForWidth());
        pixmapLabel->setSizePolicy(sizePolicy);
        pixmapLabel->setMinimumSize(QSize(128, 128));

        hboxLayout->addWidget(pixmapLabel);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        TextLabel5 = new QLabel(ConnectionWidget);
        TextLabel5->setObjectName(QStringLiteral("TextLabel5"));
        QSizePolicy sizePolicy1(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(TextLabel5->sizePolicy().hasHeightForWidth());
        TextLabel5->setSizePolicy(sizePolicy1);
        QFont font;
        font.setPointSize(13);
        font.setBold(true);
        font.setWeight(75);
        TextLabel5->setFont(font);
        TextLabel5->setWordWrap(false);
        TextLabel5->setIndent(0);

        vboxLayout->addWidget(TextLabel5);

        mainTextLabel = new QLabel(ConnectionWidget);
        mainTextLabel->setObjectName(QStringLiteral("mainTextLabel"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mainTextLabel->sizePolicy().hasHeightForWidth());
        mainTextLabel->setSizePolicy(sizePolicy2);
        mainTextLabel->setLineWidth(-1);
        mainTextLabel->setMidLineWidth(5);
        mainTextLabel->setTextFormat(Qt::AutoText);
        mainTextLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        mainTextLabel->setWordWrap(true);
        mainTextLabel->setMargin(0);
        mainTextLabel->setIndent(0);

        vboxLayout->addWidget(mainTextLabel);

        hboxLayout1 = new QHBoxLayout();
        hboxLayout1->setObjectName(QStringLiteral("hboxLayout1"));
        TextLabel1 = new QLabel(ConnectionWidget);
        TextLabel1->setObjectName(QStringLiteral("TextLabel1"));
        QFont font1;
        font1.setBold(true);
        font1.setWeight(75);
        TextLabel1->setFont(font1);
        TextLabel1->setWordWrap(false);

        hboxLayout1->addWidget(TextLabel1);

        remoteHost = new QLabel(ConnectionWidget);
        remoteHost->setObjectName(QStringLiteral("remoteHost"));
        remoteHost->setFont(font1);
        remoteHost->setWordWrap(false);

        hboxLayout1->addWidget(remoteHost);


        vboxLayout->addLayout(hboxLayout1);

        cbAllowRemoteControl = new QCheckBox(ConnectionWidget);
        cbAllowRemoteControl->setObjectName(QStringLiteral("cbAllowRemoteControl"));
        sizePolicy1.setHeightForWidth(cbAllowRemoteControl->sizePolicy().hasHeightForWidth());
        cbAllowRemoteControl->setSizePolicy(sizePolicy1);

        vboxLayout->addWidget(cbAllowRemoteControl);


        hboxLayout->addLayout(vboxLayout);


        retranslateUi(ConnectionWidget);

        QMetaObject::connectSlotsByName(ConnectionWidget);
    } // setupUi

    void retranslateUi(QWidget *ConnectionWidget)
    {
        TextLabel5->setText(tr2i18n("Attention", Q_NULLPTR));
        mainTextLabel->setText(tr2i18n("Somebody is requesting a connection to your computer. Granting this will allow the remote user to watch your desktop. ", Q_NULLPTR));
        TextLabel1->setText(tr2i18n("Remote system:", Q_NULLPTR));
        remoteHost->setText(tr2i18n("123.234.123.234", Q_NULLPTR));
#ifndef UI_QT_NO_WHATSTHIS
        cbAllowRemoteControl->setWhatsThis(tr2i18n("If you turn this option on, the remote user can enter keystrokes and use your mouse pointer. This gives them full control over your computer, so be careful. When the option is disabled the remote user can only watch your screen.", Q_NULLPTR));
#endif // QT_NO_WHATSTHIS
        cbAllowRemoteControl->setText(tr2i18n("Allow remote user to &control keyboard and mouse", Q_NULLPTR));
        Q_UNUSED(ConnectionWidget);
    } // retranslateUi

};

namespace Ui {
    class ConnectionWidget: public Ui_ConnectionWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONNECTIONWIDGET_H

