// This file is generated by kconfig_compiler_kf5 from krfb.kcfg.
// All changes you do to this file will be lost.

#include "krfbconfig.h"

#include <qglobal.h>
#include <QtCore/QFile>

class KrfbConfigHelper
{
  public:
    KrfbConfigHelper() : q(nullptr) {}
    ~KrfbConfigHelper() { delete q; }
    KrfbConfig *q;
};
Q_GLOBAL_STATIC(KrfbConfigHelper, s_globalKrfbConfig)
KrfbConfig *KrfbConfig::self()
{
  if (!s_globalKrfbConfig()->q) {
    new KrfbConfig;
    s_globalKrfbConfig()->q->read();
  }

  return s_globalKrfbConfig()->q;
}

KrfbConfig::KrfbConfig(  )
  : KConfigSkeleton()
{
  Q_ASSERT(!s_globalKrfbConfig()->q);
  s_globalKrfbConfig()->q = this;
  setCurrentGroup( QStringLiteral( "MainWindow" ) );

  KConfigSkeleton::ItemBool  *itemStartMinimized;
  itemStartMinimized = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "startMinimized" ), mStartMinimized, false );
  addItem( itemStartMinimized, QStringLiteral( "startMinimized" ) );

  setCurrentGroup( QStringLiteral( "TCP" ) );

  KConfigSkeleton::ItemBool  *itemUseDefaultPort;
  itemUseDefaultPort = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useDefaultPort" ), mUseDefaultPort, true );
  addItem( itemUseDefaultPort, QStringLiteral( "useDefaultPort" ) );
  KConfigSkeleton::ItemInt  *itemPort;
  itemPort = new KConfigSkeleton::ItemInt( currentGroup(), QStringLiteral( "port" ), mPort, 5900 );
  addItem( itemPort, QStringLiteral( "port" ) );
  KConfigSkeleton::ItemBool  *itemPublishService;
  itemPublishService = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "publishService" ), mPublishService, true );
  addItem( itemPublishService, QStringLiteral( "publishService" ) );

  setCurrentGroup( QStringLiteral( "Security" ) );

  KConfigSkeleton::ItemBool  *itemNoWallet;
  itemNoWallet = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "noWallet" ), mNoWallet, false );
  addItem( itemNoWallet, QStringLiteral( "noWallet" ) );
  KConfigSkeleton::ItemBool  *itemAllowDesktopControl;
  itemAllowDesktopControl = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "allowDesktopControl" ), mAllowDesktopControl, true );
  addItem( itemAllowDesktopControl, QStringLiteral( "allowDesktopControl" ) );
  KConfigSkeleton::ItemBool  *itemAllowUnattendedAccess;
  itemAllowUnattendedAccess = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "allowUnattendedAccess" ), mAllowUnattendedAccess, false );
  addItem( itemAllowUnattendedAccess, QStringLiteral( "allowUnattendedAccess" ) );
  KConfigSkeleton::ItemString  *itemUnattendedAccessPassword;
  itemUnattendedAccessPassword = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "unattendedAccessPassword" ), mUnattendedAccessPassword );
  addItem( itemUnattendedAccessPassword, QStringLiteral( "unattendedAccessPassword" ) );
  KConfigSkeleton::ItemString  *itemDesktopSharingPassword;
  itemDesktopSharingPassword = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "desktopSharingPassword" ), mDesktopSharingPassword );
  addItem( itemDesktopSharingPassword, QStringLiteral( "desktopSharingPassword" ) );

  setCurrentGroup( QStringLiteral( "FrameBuffer" ) );

  KConfigSkeleton::ItemString  *itemPreferredFrameBufferPlugin;
  itemPreferredFrameBufferPlugin = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "preferredFrameBufferPlugin" ), mPreferredFrameBufferPlugin, QStringLiteral( "xcb" ) );
  addItem( itemPreferredFrameBufferPlugin, QStringLiteral( "preferredFrameBufferPlugin" ) );
}

KrfbConfig::~KrfbConfig()
{
  s_globalKrfbConfig()->q = nullptr;
}

