/****************************************************************************
** Meta object code from reading C++ file 'rfbserver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/krfb-17.08.3/krfb/rfbserver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rfbserver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RfbServer_t {
    QByteArrayData data[14];
    char stringdata0[178];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RfbServer_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RfbServer_t qt_meta_stringdata_RfbServer = {
    {
QT_MOC_LITERAL(0, 0, 9), // "RfbServer"
QT_MOC_LITERAL(1, 10, 5), // "start"
QT_MOC_LITERAL(2, 16, 0), // ""
QT_MOC_LITERAL(3, 17, 4), // "stop"
QT_MOC_LITERAL(4, 22, 12), // "updateScreen"
QT_MOC_LITERAL(5, 35, 12), // "QList<QRect>"
QT_MOC_LITERAL(6, 48, 13), // "modifiedTiles"
QT_MOC_LITERAL(7, 62, 20), // "updateCursorPosition"
QT_MOC_LITERAL(8, 83, 8), // "position"
QT_MOC_LITERAL(9, 92, 21), // "krfbSendServerCutText"
QT_MOC_LITERAL(10, 114, 23), // "onListenSocketActivated"
QT_MOC_LITERAL(11, 138, 21), // "pendingClientFinished"
QT_MOC_LITERAL(12, 160, 10), // "RfbClient*"
QT_MOC_LITERAL(13, 171, 6) // "client"

    },
    "RfbServer\0start\0\0stop\0updateScreen\0"
    "QList<QRect>\0modifiedTiles\0"
    "updateCursorPosition\0position\0"
    "krfbSendServerCutText\0onListenSocketActivated\0"
    "pendingClientFinished\0RfbClient*\0"
    "client"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RfbServer[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x0a /* Public */,
       3,    0,   50,    2, 0x0a /* Public */,
       4,    1,   51,    2, 0x0a /* Public */,
       7,    1,   54,    2, 0x0a /* Public */,
       9,    0,   57,    2, 0x08 /* Private */,
      10,    0,   58,    2, 0x08 /* Private */,
      11,    1,   59,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Bool,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, QMetaType::QPoint,    8,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 12,   13,

       0        // eod
};

void RfbServer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RfbServer *_t = static_cast<RfbServer *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->start();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->stop(); break;
        case 2: _t->updateScreen((*reinterpret_cast< const QList<QRect>(*)>(_a[1]))); break;
        case 3: _t->updateCursorPosition((*reinterpret_cast< const QPoint(*)>(_a[1]))); break;
        case 4: _t->krfbSendServerCutText(); break;
        case 5: _t->onListenSocketActivated(); break;
        case 6: _t->pendingClientFinished((*reinterpret_cast< RfbClient*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QRect> >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RfbClient* >(); break;
            }
            break;
        }
    }
}

const QMetaObject RfbServer::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_RfbServer.data,
      qt_meta_data_RfbServer,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *RfbServer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RfbServer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RfbServer.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RfbServer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
